@@ -41,7 +41,7 @@ Usage::
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
 import sys
-from typing import Generator, List, TYPE_CHECKING
+from typing import Iterator, List, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_neptune.type_defs import (
     DBClusterMessageTypeDef,
@@ -88,7 +88,7 @@ __all__ = (
 
 class DescribeDBClusterParameterGroupsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDBClusterParameterGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.4/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusterParameterGroups)
+    [Paginator.DescribeDBClusterParameterGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusterParameterGroups)
     """
 
     def paginate(
@@ -96,15 +96,15 @@ class DescribeDBClusterParameterGroupsPaginator(Boto3Paginator):
         DBClusterParameterGroupName: str = None,
         Filters: List[FilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DBClusterParameterGroupsMessageTypeDef, None, None]:
+    ) -> Iterator[DBClusterParameterGroupsMessageTypeDef]:
         """
-        [DescribeDBClusterParameterGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.4/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusterParameterGroups.paginate)
+        [DescribeDBClusterParameterGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusterParameterGroups.paginate)
         """
 
 
 class DescribeDBClusterParametersPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDBClusterParameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.4/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusterParameters)
+    [Paginator.DescribeDBClusterParameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusterParameters)
     """
 
     def paginate(
@@ -113,15 +113,15 @@ class DescribeDBClusterParametersPaginator(Boto3Paginator):
         Source: str = None,
         Filters: List[FilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DBClusterParameterGroupDetailsTypeDef, None, None]:
+    ) -> Iterator[DBClusterParameterGroupDetailsTypeDef]:
         """
-        [DescribeDBClusterParameters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.4/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusterParameters.paginate)
+        [DescribeDBClusterParameters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusterParameters.paginate)
         """
 
 
 class DescribeDBClusterSnapshotsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDBClusterSnapshots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.4/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusterSnapshots)
+    [Paginator.DescribeDBClusterSnapshots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusterSnapshots)
     """
 
     def paginate(
@@ -133,15 +133,15 @@ class DescribeDBClusterSnapshotsPaginator(Boto3Paginator):
         IncludeShared: bool = None,
         IncludePublic: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DBClusterSnapshotMessageTypeDef, None, None]:
+    ) -> Iterator[DBClusterSnapshotMessageTypeDef]:
         """
-        [DescribeDBClusterSnapshots.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.4/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusterSnapshots.paginate)
+        [DescribeDBClusterSnapshots.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusterSnapshots.paginate)
         """
 
 
 class DescribeDBClustersPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDBClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.4/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusters)
+    [Paginator.DescribeDBClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusters)
     """
 
     def paginate(
@@ -149,15 +149,15 @@ class DescribeDBClustersPaginator(Boto3Paginator):
         DBClusterIdentifier: str = None,
         Filters: List[FilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DBClusterMessageTypeDef, None, None]:
+    ) -> Iterator[DBClusterMessageTypeDef]:
         """
-        [DescribeDBClusters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.4/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusters.paginate)
+        [DescribeDBClusters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusters.paginate)
         """
 
 
 class DescribeDBEngineVersionsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDBEngineVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.4/reference/services/neptune.html#Neptune.Paginator.DescribeDBEngineVersions)
+    [Paginator.DescribeDBEngineVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Paginator.DescribeDBEngineVersions)
     """
 
     def paginate(
@@ -170,15 +170,15 @@ class DescribeDBEngineVersionsPaginator(Boto3Paginator):
         ListSupportedCharacterSets: bool = None,
         ListSupportedTimezones: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DBEngineVersionMessageTypeDef, None, None]:
+    ) -> Iterator[DBEngineVersionMessageTypeDef]:
         """
-        [DescribeDBEngineVersions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.4/reference/services/neptune.html#Neptune.Paginator.DescribeDBEngineVersions.paginate)
+        [DescribeDBEngineVersions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Paginator.DescribeDBEngineVersions.paginate)
         """
 
 
 class DescribeDBInstancesPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDBInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.4/reference/services/neptune.html#Neptune.Paginator.DescribeDBInstances)
+    [Paginator.DescribeDBInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Paginator.DescribeDBInstances)
     """
 
     def paginate(
@@ -186,15 +186,15 @@ class DescribeDBInstancesPaginator(Boto3Paginator):
         DBInstanceIdentifier: str = None,
         Filters: List[FilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DBInstanceMessageTypeDef, None, None]:
+    ) -> Iterator[DBInstanceMessageTypeDef]:
         """
-        [DescribeDBInstances.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.4/reference/services/neptune.html#Neptune.Paginator.DescribeDBInstances.paginate)
+        [DescribeDBInstances.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Paginator.DescribeDBInstances.paginate)
         """
 
 
 class DescribeDBParameterGroupsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDBParameterGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.4/reference/services/neptune.html#Neptune.Paginator.DescribeDBParameterGroups)
+    [Paginator.DescribeDBParameterGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Paginator.DescribeDBParameterGroups)
     """
 
     def paginate(
@@ -202,15 +202,15 @@ class DescribeDBParameterGroupsPaginator(Boto3Paginator):
         DBParameterGroupName: str = None,
         Filters: List[FilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DBParameterGroupsMessageTypeDef, None, None]:
+    ) -> Iterator[DBParameterGroupsMessageTypeDef]:
         """
-        [DescribeDBParameterGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.4/reference/services/neptune.html#Neptune.Paginator.DescribeDBParameterGroups.paginate)
+        [DescribeDBParameterGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Paginator.DescribeDBParameterGroups.paginate)
         """
 
 
 class DescribeDBParametersPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDBParameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.4/reference/services/neptune.html#Neptune.Paginator.DescribeDBParameters)
+    [Paginator.DescribeDBParameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Paginator.DescribeDBParameters)
     """
 
     def paginate(
@@ -219,15 +219,15 @@ class DescribeDBParametersPaginator(Boto3Paginator):
         Source: str = None,
         Filters: List[FilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DBParameterGroupDetailsTypeDef, None, None]:
+    ) -> Iterator[DBParameterGroupDetailsTypeDef]:
         """
-        [DescribeDBParameters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.4/reference/services/neptune.html#Neptune.Paginator.DescribeDBParameters.paginate)
+        [DescribeDBParameters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Paginator.DescribeDBParameters.paginate)
         """
 
 
 class DescribeDBSubnetGroupsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDBSubnetGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.4/reference/services/neptune.html#Neptune.Paginator.DescribeDBSubnetGroups)
+    [Paginator.DescribeDBSubnetGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Paginator.DescribeDBSubnetGroups)
     """
 
     def paginate(
@@ -235,15 +235,15 @@ class DescribeDBSubnetGroupsPaginator(Boto3Paginator):
         DBSubnetGroupName: str = None,
         Filters: List[FilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DBSubnetGroupMessageTypeDef, None, None]:
+    ) -> Iterator[DBSubnetGroupMessageTypeDef]:
         """
-        [DescribeDBSubnetGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.4/reference/services/neptune.html#Neptune.Paginator.DescribeDBSubnetGroups.paginate)
+        [DescribeDBSubnetGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Paginator.DescribeDBSubnetGroups.paginate)
         """
 
 
 class DescribeEngineDefaultParametersPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeEngineDefaultParameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.4/reference/services/neptune.html#Neptune.Paginator.DescribeEngineDefaultParameters)
+    [Paginator.DescribeEngineDefaultParameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Paginator.DescribeEngineDefaultParameters)
     """
 
     def paginate(
@@ -251,15 +251,15 @@ class DescribeEngineDefaultParametersPaginator(Boto3Paginator):
         DBParameterGroupFamily: str,
         Filters: List[FilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeEngineDefaultParametersResultTypeDef, None, None]:
+    ) -> Iterator[DescribeEngineDefaultParametersResultTypeDef]:
         """
-        [DescribeEngineDefaultParameters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.4/reference/services/neptune.html#Neptune.Paginator.DescribeEngineDefaultParameters.paginate)
+        [DescribeEngineDefaultParameters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Paginator.DescribeEngineDefaultParameters.paginate)
         """
 
 
 class DescribeEventSubscriptionsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeEventSubscriptions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.4/reference/services/neptune.html#Neptune.Paginator.DescribeEventSubscriptions)
+    [Paginator.DescribeEventSubscriptions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Paginator.DescribeEventSubscriptions)
     """
 
     def paginate(
@@ -267,15 +267,15 @@ class DescribeEventSubscriptionsPaginator(Boto3Paginator):
         SubscriptionName: str = None,
         Filters: List[FilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[EventSubscriptionsMessageTypeDef, None, None]:
+    ) -> Iterator[EventSubscriptionsMessageTypeDef]:
         """
-        [DescribeEventSubscriptions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.4/reference/services/neptune.html#Neptune.Paginator.DescribeEventSubscriptions.paginate)
+        [DescribeEventSubscriptions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Paginator.DescribeEventSubscriptions.paginate)
         """
 
 
 class DescribeEventsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeEvents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.4/reference/services/neptune.html#Neptune.Paginator.DescribeEvents)
+    [Paginator.DescribeEvents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Paginator.DescribeEvents)
     """
 
     def paginate(
@@ -295,15 +295,15 @@ class DescribeEventsPaginator(Boto3Paginator):
         EventCategories: List[str] = None,
         Filters: List[FilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[EventsMessageTypeDef, None, None]:
+    ) -> Iterator[EventsMessageTypeDef]:
         """
-        [DescribeEvents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.4/reference/services/neptune.html#Neptune.Paginator.DescribeEvents.paginate)
+        [DescribeEvents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Paginator.DescribeEvents.paginate)
         """
 
 
 class DescribeOrderableDBInstanceOptionsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeOrderableDBInstanceOptions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.4/reference/services/neptune.html#Neptune.Paginator.DescribeOrderableDBInstanceOptions)
+    [Paginator.DescribeOrderableDBInstanceOptions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Paginator.DescribeOrderableDBInstanceOptions)
     """
 
     def paginate(
@@ -315,15 +315,15 @@ class DescribeOrderableDBInstanceOptionsPaginator(Boto3Paginator):
         Vpc: bool = None,
         Filters: List[FilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[OrderableDBInstanceOptionsMessageTypeDef, None, None]:
+    ) -> Iterator[OrderableDBInstanceOptionsMessageTypeDef]:
         """
-        [DescribeOrderableDBInstanceOptions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.4/reference/services/neptune.html#Neptune.Paginator.DescribeOrderableDBInstanceOptions.paginate)
+        [DescribeOrderableDBInstanceOptions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Paginator.DescribeOrderableDBInstanceOptions.paginate)
         """
 
 
 class DescribePendingMaintenanceActionsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribePendingMaintenanceActions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.4/reference/services/neptune.html#Neptune.Paginator.DescribePendingMaintenanceActions)
+    [Paginator.DescribePendingMaintenanceActions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Paginator.DescribePendingMaintenanceActions)
     """
 
     def paginate(
@@ -331,7 +331,7 @@ class DescribePendingMaintenanceActionsPaginator(Boto3Paginator):
         ResourceIdentifier: str = None,
         Filters: List[FilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[PendingMaintenanceActionsMessageTypeDef, None, None]:
+    ) -> Iterator[PendingMaintenanceActionsMessageTypeDef]:
         """
-        [DescribePendingMaintenanceActions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.4/reference/services/neptune.html#Neptune.Paginator.DescribePendingMaintenanceActions.paginate)
+        [DescribePendingMaintenanceActions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Paginator.DescribePendingMaintenanceActions.paginate)
         """
